# extracted from sip.h, SIP_API_MAJOR_NR SIP_API_MINOR_NR defines
%define _sip_api_major 12
%define _sip_api_minor 7
%define _sip_api       %{_sip_api_major}.%{_sip_api_minor}

Name:           python-sip
Epoch:          1
Version:        4.19.24
Release:        %mkrel 1
Summary:        SIP - Python/C++ Bindings Generator
License:        GPLv2+
Group:          Development/Python
URL:            http://www.riverbankcomputing.co.uk/software/sip/intro
Source0:        https://www.riverbankcomputing.com/static/Downloads/sip/%{version}/sip-%{version}.tar.gz
Source10: sip-wrapper.sh
## upstream patches

## upstreamable patches
# make install should not strip (by default), kills -debuginfo
Patch50:        sip-4.18-no_strip.patch
# Avoid hardcoding sip.so (needed for wxpython's siplib.so)
Patch53:        sip-4.19.18-no_hardcode_sip_so.patch

BuildRequires:  pkgconfig(bzip2)

%description
SIP is a tool that makes it very easy to create Python bindings for C and C++
libraries.
It was originally developed to create PyQt, the Python bindings for the Qt
toolkit, but can be used to create bindings for any C or C++ library.

#------------------------------------------------------------
### Python3 ###

%package -n     python3-sip
Summary:        SIP - Python 3/C++ Bindings Generator
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-sip-api(%{_sip_api_major}) = %{_sip_api}
Conflicts:	python2-sip < %{epoch}:%{version}-%{release}

%description -n python3-sip
This is the Python 3 build of SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-sip
%doc NEWS README
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%{_sysconfdir}/rpm/macros.d/sip.macros
%{python3_sitearch}/sip.so
%{python3_sitearch}/sip*.py*
%{python3_sitearch}/sip-%{version}.dist-info/
%{python3_sitearch}/__pycache__/*

#------------------------------------------------------------

%package -n     python3-sip-devel
Summary:        Files needed to generate Python 3 bindings for any C++ class library
Group:          Development/Python
Requires:       python3-sip = %{epoch}:%{version}
Requires:       pkgconfig(python3)

%description -n python3-sip-devel
This package contains files needed to generate Python 3 bindings for any C++
classes library.

%files -n python3-sip-devel
# Note that the "sip" binary is invoked by name in a few places higher up
# in the KDE-Python stack; these will need changing to "python3-sip":
%{_bindir}/sip
%{_bindir}/python3-sip
# sip-wrappers
%{_bindir}/sip-pyqt4
%{_bindir}/sip-pyqt5
%{_bindir}/sip-wx
%{_datadir}/python3-sip/
%{_includedir}/python%{python3_version}/*

#------------------------------------------------------------

%package -n     python3-pyqt4-sip
Summary:        SIP - Python 3/C++ Bindings Generator for pyqt4
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-pyqt4-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-pyqt4-sip
This is the Python 3 build of pyqt4-SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-pyqt4-sip
%doc NEWS README
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%{python3_sitearch}/PyQt4/sip.*
%{python3_sitearch}/PyQt4_sip-%{version}.dist-info/

#------------------------------------------------------------

%package -n     python3-pyqt5-sip
Summary:        SIP - Python 3/C++ Bindings Generator for pyqt5
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-pyqt5-sip-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-pyqt5-sip
This is the Python 3 build of pyqt5-SIP.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-pyqt5-sip
%doc NEWS README
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%{python3_sitearch}/PyQt5/sip.*
%{python3_sitearch}/PyQt5_sip-%{version}.dist-info/

#------------------------------------------------------------

%package -n     python3-wx-siplib
Summary:        SIP - Python 3/C++ Bindings Generator for wx
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Provides:       python3-wx-siplib-api(%{_sip_api_major}) = %{_sip_api}

%description -n python3-wx-siplib
This is the Python 3 build of wx-siplib.

SIP is a tool for generating bindings for C++ classes so that they can be
accessed as normal Python 3 classes. SIP takes many of its ideas from SWIG but,
because it is specifically designed for C++ and Python, is able to generate
tighter bindings. SIP is so called because it is a small SWIG.

SIP was originally designed to generate Python bindings for KDE and so has
explicit support for the signal slot mechanism used by the Qt/KDE class
libraries. However, SIP can be used to generate Python 3 bindings for any C++
class library.

%files -n python3-wx-siplib
%doc NEWS README
%license LICENSE LICENSE-GPL2 LICENSE-GPL3
%dir %{python3_sitearch}/wx/
%{python3_sitearch}/wx/siplib.*
%{python3_sitearch}/wx_siplib-%{version}.dist-info/

#------------------------------------------------------------

%prep
%setup -q -n sip-%{version}
%autopatch -p1
export real_api_major=`grep SIP_API_MAJOR_NR siplib/sip.h|head -n1|awk -F' ' '{print $3}'`
export real_api_minor=`grep SIP_API_MINOR_NR siplib/sip.h|head -n1|awk -F' ' '{print $3}'`
if [ $real_api_major -ne %{_sip_api_major} ]; then
	echo 'Wrong spi major specified: Should be' $real_api_major ', but set' %{_sip_api_major}
	exit 1
fi
if [ $real_api_minor -ne %{_sip_api_minor} ]; then
	echo 'Wrong spi minor specified: Should be' $real_api_minor ', but set' %{_sip_api_minor}
	exit 1
fi

#  Don't use X11R6 prefix for includes neither libraries by default.
for file in specs/linux-*; do
    perl -p -i -e "s@/X11R6/@/@g" $file
done

%build
### Python3 ###
mkdir python3-sip
pushd python3-sip
%{__python3} ../configure.py \
             --sipdir=%{_datadir}/python3-sip \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

mkdir python3-pyqt4-sip
pushd python3-pyqt4-sip
%{__python3} ../configure.py \
             --sip-module=PyQt4.sip \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

mkdir python3-pyqt5-sip
pushd python3-pyqt5-sip
%{__python3} ../configure.py \
             --sip-module=PyQt5.sip \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd

sed -i -e 's|target = sip|target = siplib|g' siplib/siplib.sbf
mkdir python3-wx-siplib
pushd python3-wx-siplib
%{__python3} ../configure.py \
             --sip-module=wx.siplib \
             --no-tools \
             CXXFLAGS+="%{optflags}" \
             CFLAGS+="%{optflags}" \
             LFLAGS+="%{ldflags}" \
             LIBS="%{?ldflags} -lpython%{python3_version}"

%make_build
popd
sed -i -e 's|target = siplib|target = sip|g' siplib/siplib.sbf


%install
### Python3 ###
# Perform the Python 3 installation first, to avoid stomping over the Python 2
# /usr/bin/sip:
%make_install -C python3-sip
mkdir -p %{buildroot}%{_datadir}/python3-sip
mv %{buildroot}%{_bindir}/sip %{buildroot}%{_bindir}/python3-sip
ln -s python3-sip %{buildroot}%{_bindir}/sip
%make_install -C python3-pyqt4-sip
%make_install -C python3-pyqt5-sip
%make_install -C python3-wx-siplib
mv %{buildroot}%{python3_sitearch}/wx/sip.pyi %{buildroot}%{python3_sitearch}/wx/siplib.pyi

mkdir -p %{buildroot}%{_sysconfdir}/rpm/macros.d/
cat > %{buildroot}%{_sysconfdir}/rpm/macros.d/sip.macros << EOF
# extracted from sip.h, SIP_API_MAJOR_NR SIP_API_MINOR_NR defines
%%_sip_api_major %{_sip_api_major}
%%_sip_api_minor %{_sip_api_minor}
%%_sip_api       %{_sip_api_major}.%{_sip_api_minor}
EOF

# sip-wrapper
install %{SOURCE10} %{buildroot}%{_bindir}/sip-pyqt4
install %{SOURCE10} %{buildroot}%{_bindir}/sip-pyqt5
install %{SOURCE10} %{buildroot}%{_bindir}/sip-wx
sed -i -e 's|@SIP_MODULE@|PyQt4.sip|g' %{buildroot}%{_bindir}/sip-pyqt4
sed -i -e 's|@SIP_MODULE@|PyQt5.sip|g' %{buildroot}%{_bindir}/sip-pyqt5
sed -i -e 's|@SIP_MODULE@|wx.siplib|g' %{buildroot}%{_bindir}/sip-wx


%changelog
* Sun Sep 13 2020 daviddavid <daviddavid> 1:4.19.24-1.mga8
+ Revision: 1625511
- new version: 4.19.24

* Mon Jun 08 2020 daviddavid <daviddavid> 1:4.19.23-1.mga8
+ Revision: 1591021
- new version: 4.19.23

* Wed Jun 03 2020 daviddavid <daviddavid> 1:4.19.22-1.mga8
+ Revision: 1590132
- new version: 4.19.22

* Thu Feb 20 2020 umeabot <umeabot> 1:4.19.21-2.mga8
+ Revision: 1546206
- Mageia 8 Mass Rebuild

* Sat Feb 01 2020 daviddavid <daviddavid> 1:4.19.21-1.mga8
+ Revision: 1486166
- new version: 4.19.21

* Sat Dec 21 2019 daviddavid <daviddavid> 1:4.19.20-1.mga8
+ Revision: 1469212
- new version: 4.19.20

* Fri Sep 27 2019 tv <tv> 1:4.19.19-3.mga8
+ Revision: 1447550
- add wrappers from FC for python-wxpython4

* Mon Sep 16 2019 daviddavid <daviddavid> 1:4.19.19-2.mga8
+ Revision: 1442024
- fix conflict adding missing epoch to ease upgrade

* Sun Sep 15 2019 daviddavid <daviddavid> 1:4.19.19-1.mga8
+ Revision: 1441087
- new version: 4.19.19
- sip_api_minor is now 7

* Fri Sep 06 2019 daviddavid <daviddavid> 1:4.19.18-6.mga8
+ Revision: 1437713
- fix sip bin symlink

* Thu Sep 05 2019 tv <tv> 1:4.19.18-5.mga8
+ Revision: 1437596
- try to workaround debug build issue that happen on BS
- provides /bin/sip

* Thu Sep 05 2019 tv <tv> 1:4.19.18-4.mga8
+ Revision: 1437527
- rebuild for python-3.8
- drop python2 sub pkg

* Fri Aug 30 2019 daviddavid <daviddavid> 1:4.19.18-3.mga8
+ Revision: 1435274
- fix default_sip_dir in python3 version of sipconfig.py also for wx-siplib

* Thu Aug 29 2019 daviddavid <daviddavid> 1:4.19.18-2.mga8
+ Revision: 1435162
- build a namespaced sip module, wx.siplib, for wxpython

* Thu Jul 11 2019 daviddavid <daviddavid> 1:4.19.18-1.mga8
+ Revision: 1420033
- new version: 4.19.18

* Sun Jun 30 2019 daviddavid <daviddavid> 1:4.19.17-1.mga8
+ Revision: 1416321
- new version: 4.19.17

* Thu Apr 11 2019 daviddavid <daviddavid> 1:4.19.16-1.mga7
+ Revision: 1388502
- new version: 4.19.16

* Fri Mar 22 2019 tv <tv> 1:4.19.15-2.mga7
+ Revision: 1379549
- fix description wrapping

* Fri Mar 22 2019 daviddavid <daviddavid> 1:4.19.15-1.mga7
+ Revision: 1379543
- new version: 4.19.15
- remove merged upstream patch

* Tue Feb 19 2019 daviddavid <daviddavid> 1:4.19.14-2.mga7
+ Revision: 1368485
- add upstream patch to fix a code generation regression specific to PyQt4

* Wed Feb 13 2019 daviddavid <daviddavid> 1:4.19.14-1.mga7
+ Revision: 1366618
- new version: 4.19.14

* Mon Jan 07 2019 shlomif <shlomif> 1:4.19.13-2.mga7
+ Revision: 1350353
- rebuild for python3 3.7

* Thu Oct 04 2018 daviddavid <daviddavid> 1:4.19.13-1.mga7
+ Revision: 1317523
- new version: 4.19.13

* Sun Sep 23 2018 wally <wally> 1:4.19.12-6.mga7
+ Revision: 1302142
- simplify build

* Sun Sep 23 2018 wally <wally> 1:4.19.12-5.mga7
+ Revision: 1301118
- fix default_sip_dir in python3 version of sipconfig.py
- drop unneeded obsoletes/provides
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 daviddavid <daviddavid> 1:4.19.12-4.mga7
+ Revision: 1251580
- add also the PyQt4 support
- include dist-info

* Sun Jul 22 2018 daviddavid <daviddavid> 1:4.19.12-3.mga7
+ Revision: 1244900
- provides python2-sip-devel from main sip pkg

* Sun Jul 22 2018 daviddavid <daviddavid> 1:4.19.12-2.mga7
+ Revision: 1244847
- fix sip_api_minor as it is now 5

* Wed Jul 11 2018 daviddavid <daviddavid> 1:4.19.12-1.mga7
+ Revision: 1243025
- new version: 4.19.12
- add the PyQt5 support

* Sat Jul 07 2018 daviddavid <daviddavid> 1:4.19.11-2.mga7
+ Revision: 1242452
- make python2-sip depend now on python2-enum34
  * https://www.riverbankcomputing.com/hg/sip/rev/379da5a152c4

* Thu Jul 05 2018 daviddavid <daviddavid> 1:4.19.11-1.mga7
+ Revision: 1241757
- new version: 4.19.11
- remove merged upstream patch

* Sun Jun 24 2018 daviddavid <daviddavid> 1:4.19.10-1.mga7
+ Revision: 1239318
- new version: 4.19.10

* Sun Jun 24 2018 daviddavid <daviddavid> 1:4.19.9-1.mga7
+ Revision: 1239313
- new version: 4.19.9

* Wed Apr 18 2018 daviddavid <daviddavid> 1:4.19.8-2.mga7
+ Revision: 1219798
- fix provide (missing epoch)

* Wed Apr 18 2018 daviddavid <daviddavid> 1:4.19.8-1.mga7
+ Revision: 1219792
- new version: 4.19.8
- rename python-sip to python2-sip

* Fri Aug 04 2017 daviddavid <daviddavid> 1:4.19.3-1.mga7
+ Revision: 1134661
- new version: 4.19.3

* Fri Aug 04 2017 tv <tv> 1:4.18.1-3.mga7
+ Revision: 1134532
- rebuild for new python

* Fri Aug 04 2017 tv <tv> 1:4.18.1-2.mga7
+ Revision: 1134530
- rebuild for new python

* Thu Aug 11 2016 luigiwalser <luigiwalser> 1:4.18.1-1.mga6
+ Revision: 1045526
- 4.18.1

* Sat Jun 25 2016 akien <akien> 1:4.18-2.mga6
+ Revision: 1037682
- Modernize spec file
- Remove unnecessary _disable_ld_no_undefined
- Rebuild in Core Release

* Fri Jun 24 2016 akien <akien> 1:4.18-1.mga6
+ Revision: 1037435
- Version 4.18

* Tue Jan 19 2016 luigiwalser <luigiwalser> 1:4.17-1.mga6
+ Revision: 925926
- 4.17

* Wed Oct 07 2015 joequant <joequant> 1:4.16.9-4.mga6
+ Revision: 886940
- upgrade python 3.5

* Wed Oct 07 2015 tv <tv> 1:4.16.9-3.mga6
+ Revision: 886740
- rebuild for python 3.5

* Thu Sep 24 2015 philippem <philippem> 1:4.16.9-2.mga6
+ Revision: 883366
- fix build, clean macros

* Thu Aug 13 2015 fwang <fwang> 1:4.16.9-1.mga6
+ Revision: 864184
- 4.16.9

* Wed Dec 03 2014 lmenut <lmenut> 1:4.16.4-1.mga5
+ Revision: 800525
- Update to 4.16.4

* Wed Oct 15 2014 umeabot <umeabot> 1:4.16.3-2.mga5
+ Revision: 750595
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 lmenut <lmenut> 1:4.16.3-1.mga5
+ Revision: 734450
- update to 4.16.3

* Sat Sep 27 2014 tv <tv> 1:4.16.1-3.mga5
+ Revision: 729766
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:4.16.1-2.mga5
+ Revision: 688335
- Mageia 5 Mass Rebuild

* Tue Jun 10 2014 fwang <fwang> 1:4.16.1-1.mga5
+ Revision: 635350
- 4.16.1

* Tue Jun 03 2014 lmenut <lmenut> 1:4.16-3.mga5
+ Revision: 630760
- add upstream patch to fix PyQt 4.11 build

* Sat May 31 2014 pterjan <pterjan> 1:4.16-2.mga5
+ Revision: 629014
- Rebuild for new Python

* Wed May 28 2014 fwang <fwang> 1:4.16-1.mga5
+ Revision: 627185
- 4.16

* Mon Mar 17 2014 fwang <fwang> 1:4.15.5-1.mga5
+ Revision: 604306
- 4.15.5

* Sun Mar 09 2014 wally <wally> 1:4.15.4-2.mga5
+ Revision: 601549
- obsolete sip-macros (leftover from wrongly imported sip pkg)

* Tue Feb 04 2014 fwang <fwang> 1:4.15.4-1.mga5
+ Revision: 581623
- new version 4.15.4

* Mon Oct 28 2013 philippem <philippem> 1:4.15.3-1.mga4
+ Revision: 547627
- Update to 4.15.3. This is a bug fix release for a regression that affects PyQtChart.

* Sat Oct 19 2013 umeabot <umeabot> 1:4.15.2-2.mga4
+ Revision: 534806
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 lmenut <lmenut> 1:4.15.2-1.mga4
+ Revision: 478912
- new version 4.15.2

* Thu Aug 29 2013 fwang <fwang> 1:4.15.1-1.mga4
+ Revision: 472845
- new version 4.15.1

* Thu Aug 29 2013 fwang <fwang> 1:4.15-1.mga4
+ Revision: 472815
- new version 4.15

* Tue Jun 18 2013 fwang <fwang> 1:4.14.7-1.mga4
+ Revision: 444289
- new version 4.14.7

* Sun Jun 09 2013 fwang <fwang> 1:4.14.6-1.mga4
+ Revision: 441306
- new version 4.14.6

* Sun Jan 13 2013 umeabot <umeabot> 1:4.14.2-2.mga3
+ Revision: 379522
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 09 2012 fwang <fwang> 1:4.14.2-1.mga3
+ Revision: 329173
- new version 4.14.2

* Mon Oct 29 2012 fwang <fwang> 1:4.14.1-1.mga3
+ Revision: 311409
- bump sip minor
- new version 4.14.1

* Tue Oct 09 2012 fwang <fwang> 1:4.14-2.mga3
+ Revision: 303728
- link with libpython3

* Tue Oct 09 2012 fwang <fwang> 1:4.14-1.mga3
+ Revision: 303723
- new version 4.14
- new version 4.14

* Sat Sep 29 2012 fwang <fwang> 1:4.13.3-2.mga3
+ Revision: 300315
- rebuild for new python3.3
- fix libmajor extraction

* Mon Jun 25 2012 fwang <fwang> 1:4.13.3-1.mga3
+ Revision: 263394
- new version 4.13.3

* Wed Jun 13 2012 fwang <fwang> 1:4.13.2-3.mga3
+ Revision: 260327
- obsoletes wrongly imported sip package

* Wed Jun 13 2012 shlomif <shlomif> 1:4.13.2-2.mga3
+ Revision: 260323
- Now building a python3 package too (import changes from Fedora .spec)

* Tue Feb 21 2012 philippem <philippem> 1:4.13.2-1.mga2
+ Revision: 211544
- Update to 4.13.2.

* Mon Dec 26 2011 fwang <fwang> 1:4.13.1-1.mga2
+ Revision: 187679
- new version 4.13.1

* Mon Oct 31 2011 fwang <fwang> 1:4.13-1.mga2
+ Revision: 160338
- new version 4.13
- add api check in pre section
- new version 4.12.4

* Fri Jun 17 2011 fwang <fwang> 1:4.12.3-1.mga2
+ Revision: 108617
- new version 4.12.3

* Fri Mar 25 2011 ahmad <ahmad> 1:4.12.1-2.mga1
+ Revision: 77429
- add %%_sip_api and related macros to enforce requires on sip api (idea from Fedora)
- add %%{_sysconfdir}/rpm/macros.d/sip.macros with the above macros

* Fri Mar 25 2011 ahmad <ahmad> 1:4.12.1-1.mga1
+ Revision: 77222
- update to 4.12.1

* Sun Jan 16 2011 misc <misc> 1:4.12-2.mga1
+ Revision: 20547
- rebuild for new python 2.7
+ dmorgan <dmorgan>
- imported package python-sip


* Fri Dec 24 2010 Funda Wang <fwang@mandriva.org> 1:4.12-1mdv2011.0
+ Revision: 624578
- update to new version 4.12

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 1:4.11.2-2mdv2011.0
+ Revision: 589913
- rebuild

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 1:4.11.2-1mdv2011.0
+ Revision: 589883
- new version 4.11.2

* Wed Sep 01 2010 Funda Wang <fwang@mandriva.org> 1:4.11-1mdv2011.0
+ Revision: 574999
- new version 4.11 (api 7.1->8.0)

* Sat Jul 31 2010 Funda Wang <fwang@mandriva.org> 1:4.10.5-1mdv2011.0
+ Revision: 563975
- new version 4.10.5

* Tue Jul 13 2010 Funda Wang <fwang@mandriva.org> 1:4.10.3-1mdv2011.0
+ Revision: 552366
- update to new version 4.10.3

* Thu Mar 18 2010 Funda Wang <fwang@mandriva.org> 1:4.10.1-1mdv2010.1
+ Revision: 524761
- new version 4.10.1

* Thu Jan 21 2010 Funda Wang <fwang@mandriva.org> 1:4.10-1mdv2010.1
+ Revision: 494537
- new version 4.10 final

* Thu Jan 07 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:4.10-0.20100102.1mdv2010.1
+ Revision: 487355
- New snapshot

* Thu Nov 26 2009 Funda Wang <fwang@mandriva.org> 1:4.9.3-1mdv2010.1
+ Revision: 470265
- new version 4.9.3

* Mon Nov 23 2009 Funda Wang <fwang@mandriva.org> 1:4.9.2-1mdv2010.1
+ Revision: 469296
- new version 4.9.2

* Sat Oct 24 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:4.9.1-1mdv2010.0
+ Revision: 459148
- Update to version 4.9.1 - Bugfix version

* Mon Sep 28 2009 Funda Wang <fwang@mandriva.org> 1:4.9-1mdv2010.0
+ Revision: 450450
- New version 4.9

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1:4.8.2-1mdv2010.0
+ Revision: 404082
- update to new version 4.8.2

* Thu Jun 18 2009 Helio Chissini de Castro <helio@mandriva.com> 1:4.8.1-1mdv2010.0
+ Revision: 387128
- Bugfix release 4.8.1

* Sat Jun 06 2009 Funda Wang <fwang@mandriva.org> 1:4.8-1mdv2010.0
+ Revision: 383191
- New version 4.8 final

* Sat May 30 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:4.8-0.20090528.2mdv2010.0
+ Revision: 381197
- Fix build
- New snapshot

* Fri May 29 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:4.8-0.20090528.1mdv2010.0
+ Revision: 381172
- New snapshot

* Sun May 03 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:4.8-0.20090430.1mdv2010.0
+ Revision: 370939
- Update to snapshot tarball

* Mon Jan 26 2009 Funda Wang <fwang@mandriva.org> 1:4.7.9-3mdv2009.1
+ Revision: 333675
- link against python

* Thu Dec 25 2008 Funda Wang <fwang@mandriva.org> 1:4.7.9-2mdv2009.1
+ Revision: 318558
- rebuild for new python

* Tue Nov 18 2008 Funda Wang <fwang@mandriva.org> 1:4.7.9-1mdv2009.1
+ Revision: 304175
- new version 4.7.9

* Sun Nov 09 2008 Funda Wang <fwang@mandriva.org> 1:4.7.8-1mdv2009.1
+ Revision: 301227
- New versio 4.7.8

* Sat Aug 09 2008 Funda Wang <fwang@mandriva.org> 1:4.7.7-1mdv2009.0
+ Revision: 270022
- New version 4.7.7

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 1:4.7.6-3mdv2009.0
+ Revision: 265586
- rebuild early 2009.0 package (before pixel changes)

* Tue May 27 2008 Paulo Andrade <pcpa@mandriva.com.br> 1:4.7.6-2mdv2009.0
+ Revision: 211480
- Don't use X11R6 prefix for includes neither libraries by default.

  + Funda Wang <fwang@mandriva.org>
    - fix url

* Wed May 21 2008 Funda Wang <fwang@mandriva.org> 1:4.7.6-1mdv2009.0
+ Revision: 209886
- New version 4.7.6
- obsoletes old name

  + David Walluck <walluck@mandriva.org>
    - bump release
    - fix build on x86_64
    - 4.7.5-snapshot-20080424 (required for QT 4.4 support)

  + Thierry Vignaud <tv@mandriva.org>
    - fix description-line-too-long
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1:4.7.3-1mdv2008.1
+ Revision: 116205
- update to new version 4.7.3

* Fri Nov 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1:4.7.1-1mdv2008.1
+ Revision: 107242
- update to new version 4.7.1

* Mon Aug 20 2007 Helio Chissini de Castro <helio@mandriva.com> 1:4.7-1mdv2008.0
+ Revision: 67983
- Restored external python-sip, to make it available for all python qt3 and python qt4 builds.
- import python-sip-4.7-1mdv2008.0


